# This file defines overlays
{inputs, ...}: {
  # This one brings our custom packages from the 'pkgs' directory
  additions = final: _prev: import ../packages final.pkgs;

  modifications = final: prev: {

    ulauncher = prev.ulauncher.overrideAttrs (old: {
      propagatedBuildInputs = with prev.python3Packages;
        old.propagatedBuildInputs
        ++ [
          thefuzz
          tornado
        ];
    });

    gnome47Extensions.paperwm = inputs.paperwm.packages.x86_64-linux.default;

    wineWowPackages.stagingFull = prev.wineWowPackages.stagingFull.overrideAttrs (old: {
      patches = old.patches ++ [ ./wine-6006.patch ];
      waylandSupport = true;
      fontconfigSupport = true;
      vulkanSupport = true;
    });

    raylib = prev.raylib.overrideDerivation (previous: {
      src = prev.fetchFromGitHub {
        owner = "raysan5";
        repo = "raylib";
        hash = "sha256-PHYdAEhittShd1UhASdhmq0nGHEEVZEUGcjCUUJZl9g=";
        rev = "c9c830cb971d7aa744fe3c7444b768ccd5176c4c";
      };
      patches = [""];
    });

    openrazer-daemon = prev.openrazer-daemon.overrideDerivation (previous: {
	    # name = "openrazer-daemon";
	    src = prev.fetchFromGitHub {
	      owner = "openrazer";
        version = "latest";
	      repo = "openrazer";
	      hash = "sha256-GqmFpVNuPRNM95pJsihsk/d3s61t4Lw+qaukKip9BAM=";
	      rev = "5e677b178be7da08fb72d7cd0791bf68a129fcc5";
	    };
	  });

    python312 = prev.python312.override {
      packageOverrides = pyself: pysuper: {
        openrazer = pysuper.openrazer.overrideAttrs (_: {
          src = prev.fetchFromGitHub {
	          owner = "openrazer";
	          repo = "openrazer";
	          hash = "sha256-GqmFpVNuPRNM95pJsihsk/d3s61t4Lw+qaukKip9BAM=";
	          rev = "5e677b178be7da08fb72d7cd0791bf68a129fcc5";
	        };
        });
      };
    };

    python311 = prev.python311.override {
      packageOverrides = pyself: pysuper: {
        openrazer = pysuper.openrazer.overrideAttrs (_: {
          src = prev.fetchFromGitHub {
            version = "latest";
            owner = "openrazer";
	          repo = "openrazer";
	          hash = "sha256-GqmFpVNuPRNM95pJsihsk/d3s61t4Lw+qaukKip9BAM=";
	          rev = "5e677b178be7da08fb72d7cd0791bf68a129fcc5";
	        };
        });
      };
    };

    linuxPackages_6_12 = prev.linuxPackages_6_12.extend (lpf: lpp: {
      openrazer = lpp.openrazer.overrideAttrs (_: {
        src = prev.fetchFromGitHub {
	        owner = "openrazer";
	        repo = "openrazer";
          version = "latest";
	        hash = "sha256-GqmFpVNuPRNM95pJsihsk/d3s61t4Lw+qaukKip9BAM=";
	        rev = "5e677b178be7da08fb72d7cd0791bf68a129fcc5";
	      };
      });
    });
  };

  # When applied, the unstable nixpkgs set (declared in the flake inputs) will
  # be accessible through 'pkgs.unstable'
  unstable-packages = final: _prev: {
    unstable = import inputs.nixpkgs-unstable {
      system = final.system;
      config.allowUnfree = true;
    };
  };
}
